function sigma = psnr2std(psnrval,maxval)
%PSNR2STD Translate PSNR to noise standard deviation
%  SIGMA = PSNR2STD(PSNRVAL) converts the specified PSNR value to units of
%  noise standard deviation. This assumes samples in the range [0,1].
%
%  SIGMA = PSNR2STD(PSNRVAL,MAXVAL) assumes samples in the range [0,MAXVAL]
%  rather than the default of [0,1].
%
%  The computation is given by
%
%      SIGMA = MAXVAL / 10^(PSNR/20)
%
%  See also STD2PSNR, PSNR.

%  Ron Rubinstein
%  Computer Science Department
%  Technion, Haifa 32000 Israel
%  ronrubin@cs
%
%  January 2008

if (nargin<2), maxval = 1; end

sigma = maxval/10^(psnrval/20);
